package lsgwr.exam.repository;

import lsgwr.exam.entity.Question;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import java.util.List;

/**
 * Question实体的仓库接口，用于定义对Question实体进行数据库操作的方法
 */
public interface QuestionRepository extends JpaRepository<Question, String> {

    /**
     * 根据问题类型ID查找问题
     *
     * @param id 问题类型ID
     * @return 匹配的问题类型ID的所有问题列表
     */
    List<Question> findByQuestionTypeId(Integer id);

    /**
     * 查询所有问题，并按照更新时间降序排序
     *
     * @return 所有问题列表，按更新时间降序排列
     */
    @Query("select q from Question q order by q.updateTime desc")
    List<Question> findAll();
}
