/**
 * QuestionOptionVo类用于表示考试题目中的选项信息
 * 它包含了选项的标识、内容、是否为正确答案以及选项的描述
 * 该类使用Lombok的@Data注解，自动生成getter和setter方法，简化代码
 * 使用Jackson的@JsonProperty注解，以便在序列化和反序列化JSON时映射到特定的字段
 */
package lsgwr.exam.vo;

import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Data;

/**
 * 表示考试题目选项的值对象
 */
@Data
public class QuestionOptionVo {
    /**
     * 选项的唯一标识符
     * 使用@JsonProperty注解指定JSON字段名
     */
    @JsonProperty("id")
    private String questionOptionId;

    /**
     * 选项的内容
     * 使用@JsonProperty注解指定JSON字段名
     */
    @JsonProperty("content")
    private String questionOptionContent;

    /**
     * 标识该选项是否为正确答案
     * 默认值为false
     * 使用@JsonProperty注解指定JSON字段名
     */
    @JsonProperty("answer")
    private Boolean answer = false;

    /**
     * 对选项的描述，用于提供额外的信息
     * 使用@JsonProperty注解指定JSON字段名
     */
    @JsonProperty("description")
    private String questionOptionDescription;
}
